@@ -20,10 +20,12 @@
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  * 
  */
-#include "hoel.h"
 #include <ctype.h>
 #include <string.h>
 
+#include "hoel.h"
+#include "h-private.h"
+
 /**
  * free data allocated by hoel functions
  */
@@ -309,10 +311,12 @@ struct _h_data * h_query_last_insert_id(const struct _h_connection * conn) {
 #endif
 #ifdef _HOEL_PGSQL
     } else if (conn->type == HOEL_DB_TYPE_PGSQL) {
-      // TODO
-      // Not possible ?
-      y_log_message(Y_LOG_LEVEL_ERROR, "Error feature not supported");
-      data = h_new_data_null();
+      int last_id = h_last_insert_id_pgsql(conn);
+      if (last_id > 0) {
+        data = h_new_data_int(last_id);
+      } else {
+        data = h_new_data_null();
+      }
 #endif
     } else {
       data = h_new_data_null();
@@ -373,29 +377,6 @@ int h_query_select_json(const struct _h_connection * conn, const char * query, j
   }
 }
 
-/**
- * trim_whitespace_and_double_quotes
- * Return the string without its beginning and ending whitespaces or double quotes
- */
-char * trim_whitespace_and_double_quotes(char *str) {
-  char *end;
-
-  // Trim leading space
-  while(isspace(*str) || *str == '"') str++;
-
-  if(*str == 0)  // All spaces?
-    return str;
-
-  // Trim trailing space
-  end = str + strlen(str) - 1;
-  while(end > str && (isspace(*end) || *end == '"')) end--;
-
-  // Write new null terminator
-  *(end+1) = 0;
-
-  return str;
-}
-
 /**
  * h_clean_result
  * Free all the memory allocated by the struct _h_result
